<?php
/**
 * Banner Section options
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */

// Add Banner section
$wp_customize->add_section( 'edufication_pro_banner_section', array(
	'title'             => esc_html__( 'Banner','edufication-pro' ),
	'description'       => esc_html__( 'Banner Section options.', 'edufication-pro' ),
	'panel'             => 'edufication_pro_front_page_panel',
) );

// Banner content enable control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[banner_section_enable]', array(
	'default'			=> 	$options['banner_section_enable'],
	'sanitize_callback' => 'edufication_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Edufication_Pro_Switch_Control( $wp_customize, 'edufication_pro_theme_options[banner_section_enable]', array(
	'label'             => esc_html__( 'Banner Section Enable', 'edufication-pro' ),
	'section'           => 'edufication_pro_banner_section',
	'on_off_label' 		=> edufication_pro_switch_options(),
) ) );

// Banner content type control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[banner_content_type]', array(
	'default'          	=> $options['banner_content_type'],
	'sanitize_callback' => 'edufication_pro_sanitize_select',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[banner_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'edufication-pro' ),
	'section'           => 'edufication_pro_banner_section',
	'type'				=> 'select',
	'active_callback' 	=> 'edufication_pro_is_banner_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'edufication-pro' ),
		'post' 		=> esc_html__( 'Post', 'edufication-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'edufication-pro' ),
	),
) );

// banner pages drop down chooser control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[banner_content_page]', array(
	'sanitize_callback' => 'edufication_pro_sanitize_page',
) );

$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[banner_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'edufication-pro' ),
	'section'           => 'edufication_pro_banner_section',
	'choices'			=> edufication_pro_page_choices(),
	'active_callback'	=> 'edufication_pro_is_banner_section_content_page_enable',
) ) );

// banner posts drop down chooser control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[banner_content_post]', array(
	'sanitize_callback' => 'edufication_pro_sanitize_page',
) );

$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[banner_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'edufication-pro' ),
	'section'           => 'edufication_pro_banner_section',
	'choices'			=> edufication_pro_post_choices(),
	'active_callback'	=> 'edufication_pro_is_banner_section_content_post_enable',
) ) );

// banner image setting and control.
$wp_customize->add_setting( 'edufication_pro_theme_options[banner_image]', array(
	'sanitize_callback' => 'edufication_pro_sanitize_image',
	'default'			=> $options['banner_image'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'edufication_pro_theme_options[banner_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'edufication-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'edufication-pro' ), 1920, 920 ),
		'section'     		=> 'edufication_pro_banner_section',
		'active_callback'	=> 'edufication_pro_is_banner_section_content_custom_enable',
) ) );

// banner title setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[banner_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['banner_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[banner_title]', array(
	'label'           	=> esc_html__( 'Title', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_banner_section',
	'active_callback' 	=> 'edufication_pro_is_banner_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[banner_title]', array(
		'selector'            => '#hero-section .hero-content-wrapper .section-header h2.section-title',
		'settings'            => 'edufication_pro_theme_options[banner_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_banner_title_partial',
    ) );
}

// banner description setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[banner_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['banner_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[banner_description]', array(
	'label'           	=> esc_html__( 'Description', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_banner_section',
	'active_callback' 	=> 'edufication_pro_is_banner_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[banner_description]', array(
		'selector'            => '#hero-section .hero-content-wrapper .section-content p',
		'settings'            => 'edufication_pro_theme_options[banner_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_banner_description_partial',
    ) );
}

// banner link label setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[banner_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['banner_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[banner_btn_label]', array(
	'label'           	=> esc_html__( 'Banner Button Label', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_banner_section',
	'active_callback' 	=> 'edufication_pro_is_banner_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[banner_btn_label]', array(
		'selector'            => '#hero-section .hero-content-wrapper .buttons a.btn-transparent',
		'settings'            => 'edufication_pro_theme_options[banner_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_banner_btn_label_partial',
    ) );
}

// banner link url setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[banner_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'			=> '#',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[banner_btn_link]', array(
	'label'           	=> esc_html__( 'Banner Button Link', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_banner_section',
	'active_callback' 	=> 'edufication_pro_is_banner_section_content_custom_enable',
	'type'				=> 'url',
) );

// banner additional btn label setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[banner_add_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['banner_add_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[banner_add_btn_label]', array(
	'label'           	=> esc_html__( 'Additional Button Label', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_banner_section',
	'active_callback' 	=> 'edufication_pro_is_banner_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[banner_add_btn_label]', array(
		'selector'            => '#hero-section .hero-content-wrapper .buttons a.btn-primary',
		'settings'            => 'edufication_pro_theme_options[banner_add_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_banner_add_btn_label_partial',
    ) );
}

// banner additional btn url setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[banner_add_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'			=> '#',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[banner_add_link]', array(
	'label'           	=> esc_html__( 'Additional Button Link', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_banner_section',
	'active_callback' 	=> 'edufication_pro_is_banner_section_enable',
	'type'				=> 'url',
) );