<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'edufication_pro_service_section', array(
	'title'             => esc_html__( 'Services','edufication-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'edufication-pro' ),
	'panel'             => 'edufication_pro_front_page_panel',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'edufication_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Edufication_Pro_Switch_Control( $wp_customize, 'edufication_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'edufication-pro' ),
	'section'           => 'edufication_pro_service_section',
	'on_off_label' 		=> edufication_pro_switch_options(),
) ) );

// Service content enable control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[service_modern_enable]', array(
	'default'			=> 	$options['service_modern_enable'],
	'sanitize_callback' => 'edufication_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Edufication_Pro_Switch_Control( $wp_customize, 'edufication_pro_theme_options[service_modern_enable]', array(
	'label'             => esc_html__( 'Modern Layout', 'edufication-pro' ),
	'description'       => esc_html__( 'Note: Modern Layout will work only if banner section is enabled and located after banner.', 'edufication-pro' ),
	'section'           => 'edufication_pro_service_section',
	'on_off_label' 		=> edufication_pro_switch_options(),
	'active_callback' 	=> 'edufication_pro_is_service_section_enable',
) ) );

// Services Layout control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[service_column]', array(
	'default'          	=> $options['service_column'],
	'sanitize_callback' => 'edufication_pro_sanitize_select',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[service_column]', array(
	'label'             => esc_html__( 'Layout Alignment', 'edufication-pro' ),
	'section'           => 'edufication_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'edufication_pro_is_service_section_enable',
	'choices'			=> array( 
		1 		=> esc_html__( 'Vertical Align', 'edufication-pro' ),
		2 		=> esc_html__( 'Horizontal Align', 'edufication-pro' ),
	),
) );

// service note control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[service_heading_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Edufication_Pro_Note_Control( $wp_customize, 'edufication_pro_theme_options[service_heading_label]', array(
	'label'             => esc_html__( 'Heading Section', 'edufication-pro' ),
	'section'           => 'edufication_pro_service_section',
	'active_callback'	=> 'edufication_pro_is_service_section_enable',
) ) );

// service title setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[service_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[service_title]', array(
	'label'           	=> esc_html__( 'Title', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_service_section',
	'active_callback' 	=> 'edufication_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[service_title]', array(
		'selector'            => '#our-services .section-header h2.section-title',
		'settings'            => 'edufication_pro_theme_options[service_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_service_title_partial',
    ) );
}

// service description setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[service_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['service_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[service_description]', array(
	'label'           	=> esc_html__( 'Description', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_service_section',
	'active_callback' 	=> 'edufication_pro_is_service_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[service_description]', array(
		'selector'            => '#our-services .section-content p',
		'settings'            => 'edufication_pro_theme_options[service_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_service_description_partial',
    ) );
}

// service btn label setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[service_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[service_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_service_section',
	'active_callback' 	=> 'edufication_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[service_btn_label]', array(
		'selector'            => '#our-services .section-content p',
		'settings'            => 'edufication_pro_theme_options[service_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_service_btn_label_partial',
    ) );
}

// service btn url setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[service_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'			=> '#',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[service_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_service_section',
	'active_callback' 	=> 'edufication_pro_is_service_section_enable',
	'type'				=> 'url',
) );

// service note control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[service_content_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Edufication_Pro_Note_Control( $wp_customize, 'edufication_pro_theme_options[service_content_label]', array(
	'label'             => esc_html__( 'Content Section', 'edufication-pro' ),
	'section'           => 'edufication_pro_service_section',
	'active_callback'	=> 'edufication_pro_is_service_section_enable',
) ) );

// Service content type control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'edufication_pro_sanitize_select',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'edufication-pro' ),
	'section'           => 'edufication_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'edufication_pro_is_service_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'edufication-pro' ),
		'post' 		=> esc_html__( 'Post', 'edufication-pro' ),
		'category' 	=> esc_html__( 'Category', 'edufication-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'edufication_pro_sanitize_number_range',
	'validate_callback' => 'edufication_pro_validate_service_count',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Services', 'edufication-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'edufication-pro' ),
	'section'           => 'edufication_pro_service_section',
	'active_callback'   => 'edufication_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 6,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'edufication_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_service_section',
		'choices'			=> edufication_pro_page_choices(),
		'active_callback'	=> 'edufication_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'edufication_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_service_section',
		'choices'			=> edufication_pro_post_choices(),
		'active_callback'	=> 'edufication_pro_is_service_section_content_post_enable',
	) ) );

	
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'edufication_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'edufication_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Edufication_Pro_Dropdown_Taxonomies_Control( $wp_customize,'edufication_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'edufication-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'edufication-pro' ),
	'section'           => 'edufication_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'edufication_pro_is_service_section_content_category_enable'
) ) );
