<?php
/**
 * Team section
 *
 * This is the template for the content of team section
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */
if ( ! function_exists( 'edufication_pro_add_team_section' ) ) :
    /**
    * Add team section
    *
    *@since Edufication Pro 1.0.0
    */
    function edufication_pro_add_team_section() {
    	$options = edufication_pro_get_theme_options();
        // Check if team is enabled on frontpage
        $team_enable = apply_filters( 'edufication_pro_section_status', true, 'team_section_enable' );

        if ( true !== $team_enable ) {
            return false;
        }
        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'edufication_pro_filter_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render team section now.
        edufication_pro_render_team_section( $section_details );
    }
endif;

if ( ! function_exists( 'edufication_pro_get_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since Edufication Pro 1.0.0
    * @param array $input team section details.
    */
    function edufication_pro_get_team_section_details( $input ) {
        $options = edufication_pro_get_theme_options();

        // Content type.
        $team_content_type  = $options['team_content_type'];
        $team_count = ! empty( $options['team_count'] ) ? $options['team_count'] : 4;
        
        $content = array();
        switch ( $team_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_page_' . $i] ) )
                        $page_ids[] = $options['team_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $team_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_post_' . $i] ) )
                        $post_ids[] = $options['team_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $team_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['team_content_category'] ) ? $options['team_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $team_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'tp-team':
                $post_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_team_' . $i] ) )
                        $post_ids[] = $options['team_content_team_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'tp-team',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $team_count ),
                    'orderby'           => 'post__in',
                    );                      
            break;

            case 'tp-team-cat':
                $cat_id = ! empty( $options['team_content_team_cat'] ) ? $options['team_content_team_cat'] : '';
                $args = array(
                    'post_type'         => 'tp-team',
                    'posts_per_page'    => absint( $team_count ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-team-category',
                            'field'     => 'id',
                            'terms'     => absint( $cat_id ),
                        )
                    ) );                    
            break;

            case 'recent-tp-team':
                $args = array(
                    'post_type'         => 'tp-team',
                    'posts_per_page'    => absint( $team_count ),
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = edufication_pro_trim_content( 13 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'edufication_pro_filter_team_section_details', 'edufication_pro_get_team_section_details' );


if ( ! function_exists( 'edufication_pro_render_team_section' ) ) :
  /**
   * Start team section
   *
   * @return string team content
   * @since Edufication Pro 1.0.0
   *
   */
   function edufication_pro_render_team_section( $content_details = array() ) {
        $options = edufication_pro_get_theme_options();
        $team_content_type  = $options['team_content_type'];
        $layout = ! empty( $options['team_column'] ) ? $options['team_column'] : 4;

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="our-team" class="relative page-section">
                <div class="wrapper">
                    <?php if ( ! empty( $options['team_title'] ) ) : ?>
                        <div class="section-header text-center">
                            <h2 class="section-title separator"><?php echo esc_html( $options['team_title'] ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <!-- supports col-1, col-2, col-3 and col-4 -->
                    <div class="section-content col-<?php echo absint( $layout ); ?>">
                        <?php foreach ( $content_details as $content ) : ?>
                            <article>
                                <div class="team-item-wrapper">
                                    <?php if ( ! empty( $content['image'] ) ) : ?>
                                        <div class="featured-image">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                        </div><!-- .featured-image -->
                                    <?php endif; ?>
                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            <?php if ( class_exists( 'TP_Education' ) && in_array( $team_content_type, array( 'tp-team', 'tp-team-cat', 'recent-tp-team' ) ) ) :
                                                tp_team_designation( $content['id'] );
                                            else : ?>
                                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                            <?php endif; ?>
                                        </header>

                                        <?php if ( class_exists( 'TP_Education' ) && in_array( $team_content_type, array( 'tp-team', 'tp-team-cat', 'recent-tp-team' ) ) ) : ?>
                                            <div class="social-icons">
                                                <?php tp_team_social( $content['id'] ); ?>
                                            </div>
                                        <?php endif; ?>
                                    </div><!-- .entry-container -->
                                </div><!-- .team-item-wrapper -->
                            </article>
                        <?php endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #our-team -->

    <?php }
endif;